@@ -74,7 +74,11 @@ class GStream(object):
             return
 
         # 异常也认为服务器断掉链接了，或者该断掉链接
-        data = safe_call(self.rfile.readline)
+        try:
+            data = self.rfile.readline()
+        except Exception, e:
+            logger.exception('rfile.readline fail. e: %s', e)
+            data = None
 
         if not data:
             # 重复调用也没关系
